"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    module,
)

from proto.message import (
    Message,
)

from ubii.proto.v1.dataStructure.handGestureType_pb_plus import (
    HandGestureType,
)

from ubii.proto.v1.dataStructure.quaternion_pb_plus import (
    Quaternion,
)

from ubii.proto.v1.dataStructure.vector3_pb_plus import (
    Vector3,
)

from ubii.proto.v1.dataStructure.vector8_pb_plus import (
    Vector8,
)


__protobuf__ = module(
    package="ubii.proto.v1.dataStructure",
    marshal="ubii.proto.v1",
    manifest={
        "MyoEvent",
    }
)


class MyoEvent(Message):
    """
    Attributes:
        emg (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector8_pb_plus.Vector8`
        orientation (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.quaternion_pb_plus.Quaternion`
        gyroscope (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector3_pb_plus.Vector3`
        accelerometer (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector3_pb_plus.Vector3`
        gesture (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.handGestureType_pb_plus.HandGestureType`
    """

    emg = Field(
        Vector8,
        number=1,
    )
    orientation = Field(
        Quaternion,
        number=2,
    )
    gyroscope = Field(
        Vector3,
        number=3,
    )
    accelerometer = Field(
        Vector3,
        number=4,
    )
    gesture = Field(
        HandGestureType,
        number=5,
    )

