"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    STRING,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1.servers",
    marshal="ubii.proto.v1",
    manifest={
        "Server",
    }
)


class Server(Message):
    """
    Attributes:
        id (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        name (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        ip_ethernet (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        ip_wlan (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        port_service_zmq (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        port_service_rest (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        port_topic_data_zmq (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        port_topic_data_ws (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        constants_json (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        external_address_service_zmq (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        external_address_service_http_json (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        external_address_service_http_binary (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        external_address_topic_data_zmq (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        external_address_topic_data_ws (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
    """

    id = Field(
        STRING,
        number=1,
    )
    name = Field(
        STRING,
        number=2,
    )
    ip_ethernet = Field(
        STRING,
        number=3,
    )
    ip_wlan = Field(
        STRING,
        number=4,
    )
    port_service_zmq = Field(
        STRING,
        number=5,
    )
    port_service_rest = Field(
        STRING,
        number=6,
    )
    port_topic_data_zmq = Field(
        STRING,
        number=7,
    )
    port_topic_data_ws = Field(
        STRING,
        number=8,
    )
    constants_json = Field(
        STRING,
        number=9,
    )
    external_address_service_zmq = Field(
        STRING,
        number=10,
    )
    external_address_service_http_json = Field(
        STRING,
        number=11,
    )
    external_address_service_http_binary = Field(
        STRING,
        number=12,
    )
    external_address_topic_data_zmq = Field(
        STRING,
        number=13,
    )
    external_address_topic_data_ws = Field(
        STRING,
        number=14,
    )

