"""
@generated by codestare-proto-plus.  Do not edit manually!

Note:
    __init__.py files for packages are autogenerated, and import all messages from submodules to keep import names consistent with the directory structure of the ``.proto`` source files.
"""
from .error_pb_plus import (
    Error,
    ErrorList,
)

from .success_pb_plus import (
    Success,
    SuccessList,
)


__all__ = (
    "Error",
    "ErrorList",
    "Success",
    "SuccessList",
)