syntax = "proto3";
package ubii.dataStructure;

message Quaternion {
    double x = 1;
    double y = 2;
    double z = 3;
    double w = 4;
}

message QuaternionList {
    repeated ubii.dataStructure.Quaternion elements = 1;
}