syntax = "proto3";
package ubii.topicData;

import "topicData/topicDataRecord.proto";
import "general/error.proto";

message TopicData {
    oneof type {
        ubii.topicData.TopicDataRecord topic_data_record = 2;
        ubii.topicData.TopicDataRecordList topic_data_record_list = 3;
        ubii.general.Error error = 4;
    }
}
